// (C) 2016 anser solutions
// All rights reserved
// This file is part of the Hierarchical Data Format query language (HDFql)
// For more information about HDFql, please visit the website http://www.hdfql.com

// $Rev: 99 $



//===========================================================
// The following program provides an example on how to use the HDFql Java wrapper
//===========================================================

public class HDFqlExample
{
	public static void main(String args[])
	{
		// declare variables
		HDFqlCursor myCursor;
		int data[][];
		int x;
		int y;

		// load HDFql shared library (make sure it can be found by the JVM)
		System.loadLibrary("HDFql");

		// display HDFql version in use
		System.out.println("HDFql version: " + HDFql.VERSION);

		// create an HDF file named "example_java.h5" and use (i.e. open) it
		HDFql.execute("CREATE FILE example_java.h5");
		HDFql.execute("USE FILE example_java.h5");

		// populate HDFql default cursor with the name of the HDF file in use and display it
		HDFql.execute("SHOW USE FILE");
		HDFql.cursorFirst();
		System.out.println("File in use: " + HDFql.cursorGetChar());

		// create an attribute named "example_attribute" of type float with a value of 12.4
		HDFql.execute("CREATE ATTRIBUTE example_attribute AS FLOAT DEFAULT 12.4");

		// select (i.e. read) attribute "example_attribute" and display its value
		HDFql.execute("SELECT FROM example_attribute");
		HDFql.cursorFirst();
		System.out.println("Attribute value: " + HDFql.cursorGetFloat());

		// create a dataset named "example_dataset" of type integer with dimensions 3x2
		HDFql.execute("CREATE DATASET example_dataset AS INT(3, 2)");

		// create variable "data" and populate it with certain values
		data = new int[3][2];
		for(x = 0; x < 3; x++)
		{
			for(y = 0; y < 2; y++)
			{
				data[x][y] = x * 2 + y + 1;
			}
		}

		// register variable "data" for subsequent usage
		HDFql.variableRegister(data);

		// insert (i.e. write) the content of variable "data" into dataset "example_dataset"
		HDFql.execute("INSERT INTO example_dataset VALUES FROM MEMORY " + HDFql.variableGetMemory(data) + " SIZE " + HDFql.variableGetSize(data));

		// populate variable "data" with zeros (i.e. reset variable)
		for(x = 0; x < 3; x++)
		{
			for(y = 0; y < 2; y++)
			{
				data[x][y] = 0;
			}
		}

		// select (i.e. read) dataset "example_dataset" into variable "data"
		HDFql.execute("SELECT FROM example_dataset INTO MEMORY " + HDFql.variableGetMemory(data) + " SIZE " + HDFql.variableGetSize(data));

		// display content of variable "data"
		System.out.println("Variable:");
		for(x = 0; x < 3; x++)
		{
			for(y = 0; y < 2; y++)
			{
				System.out.println(data[x][y]);
			}
		}

		// unregister variable "data" as it is no longer used/needed
		HDFql.variableUnregister(data);

		// another way to select dataset "example_dataset" using HDFql default cursor
		HDFql.execute("SELECT FROM example_dataset");

		// display content of HDFql default cursor
		System.out.println("Cursor:");
		while (HDFql.cursorNext() == HDFql.SUCCESS)
		{
			System.out.println(HDFql.cursorGetInt());
		}

		// create cursor "myCursor" and use it
		myCursor = new HDFqlCursor();
		HDFql.cursorUse(myCursor);

		// populate cursor "myCursor" with size of dataset "example_dataset" and display it
		HDFql.execute("SHOW SIZE example_dataset");
		HDFql.cursorFirst();
		System.out.println("Dataset size: " + HDFql.cursorGetInt());
	}
}

