# (C) 2016 anser solutions
# All rights reserved
# This file is part of the Hierarchical Data Format query language (HDFql)
# For more information about HDFql, please visit the website http://www.hdfql.com

# $Rev: 99 $



#===========================================================
# The following script provides an example on how to use the HDFql Python wrapper
#===========================================================

# import HDFql module (make sure it can be found by the Python interpreter)
import HDFql

# import other relevant modules
import sys
import numpy

# display HDFql version in use
print "HDFql version: %s" % HDFql.VERSION

# create an HDF file named "example_python.h5" and use (i.e. open) it
HDFql.execute("CREATE FILE example_python.h5")
HDFql.execute("USE FILE example_python.h5")

# populate HDFql default cursor with the name of the HDF file in use and display it
HDFql.execute("SHOW USE FILE")
HDFql.cursor_first()
print "File in use: %s" % HDFql.cursor_get_char()

# create an attribute named "example_attribute" of type float with a value of 12.4
HDFql.execute("CREATE ATTRIBUTE example_attribute AS FLOAT DEFAULT 12.4")

# select (i.e. read) attribute "example_attribute" and display its value
HDFql.execute("SELECT FROM example_attribute")
HDFql.cursor_first()
print "Attribute value: %f" % HDFql.cursor_get_float()

# create a dataset named "example_dataset" of type integer with dimensions 3x2
HDFql.execute("CREATE DATASET example_dataset AS INT(3, 2)")

# create variable "data" and populate it with certain values
data = numpy.zeros((3, 2), dtype = numpy.int32)
for x in range(3):
	for y in range(2):
		data[x][y] = x * 2 + y + 1

# register variable "data" for subsequent usage
HDFql.variable_register(data)

# insert (i.e. write) the content of variable "data" into dataset "example_dataset"
HDFql.execute("INSERT INTO example_dataset VALUES FROM MEMORY %d SIZE %d" % (HDFql.variable_get_memory(data), HDFql.variable_get_size(data)))

# populate variable "data" with zeros (i.e. reset variable)
for x in range(3):
	for y in range(2):
		data[x][y] = 0

# select (i.e. read) dataset "example_dataset" into variable "data"
HDFql.execute("SELECT FROM example_dataset INTO MEMORY %d SIZE %d" % (HDFql.variable_get_memory(data), HDFql.variable_get_size(data)))

# display content of variable "data"
print "Variable:"
for x in range(3):
	for y in range(2):
		print data[x][y]

# unregister variable "data" as it is no longer used/needed
HDFql.variable_unregister(data)

# another way to select dataset "example_dataset" using HDFql default cursor
HDFql.execute("SELECT FROM example_dataset")

# display content of HDFql default cursor
print "Cursor:"
while HDFql.cursor_next() == HDFql.SUCCESS:
	print HDFql.cursor_get_int()

# create cursor "my_cursor" and use it
my_cursor = HDFql.Cursor()
HDFql.cursor_use(my_cursor)

# populate cursor "my_cursor" with size of dataset "example_dataset" and display it
HDFql.execute("SHOW SIZE example_dataset")
HDFql.cursor_first()
print "Dataset size: %d" % HDFql.cursor_get_int()

